# pyRho

pyRho is a set of tools for processing volumetric data for material science applications.

pyRho is written in [Python](http://docs.python-guide.org/en/latest/) and supports Python 3.7+.

## Installation from source

You can install pyRho directly from a clone of the [Git repository](https://github.com/materialsproject/pyrho).  This can be done either by cloning the repo and installing from the local clone, or simply installing directly via **git**.

``` shell tab="Local Clone"
git clone https://github.com/jmmshn/pyRho
cd pyrho
python setup.py install
```
